===========
scrapereads
===========

scrapereads.api
===============

.. automodule:: scrapereads.api
    :members:

scrapereads.meta
================

.. automodule:: scrapereads.meta
    :members:

scrapereads.connect
====================

.. automodule:: scrapereads.connect
    :members:

scrapereads.scrape
==================

.. automodule:: scrapereads.scrape
    :members:

scrapereads.utils
=================

.. automodule:: scrapereads.utils
    :members:

=================
scrapereads.reads
=================

scrapereads.reads.author
=========================

.. automodule:: scrapereads.reads.author
    :members:

scrapereads.reads.book
=======================

.. automodule:: scrapereads.reads.book
    :members:

scrapereads.reads.quote
=======================

.. automodule:: scrapereads.reads.quote
    :members:


